@@ -1,6 +1,10 @@
 `wa.formula` <- function(formula, data, subset, na.action,
                          deshrink = c("inverse", "classical", "expanded", "none"),
-                         tol.dw = FALSE, ..., model = FALSE) {
+                         tol.dw = FALSE, useN2 = TRUE,
+                         na.tol = c("min","mean","max"),
+                         small.tol = c("min","fraction","absolute"),
+                         min.tol = NULL, f = 0.1, ...,
+                         model = FALSE) {
     ## set default deshrinking to inverse if no supplied
     if(missing(deshrink))
         deshrink <- "inverse"
